package com.citizen.app.assist;

import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;

import android.graphics.Typeface;
import android.util.Log;

import com.citizen.jpos.command.ESCPOS;
import com.citizen.jpos.command.ESCPOSConst;
import com.citizen.jpos.printer.ESCPOSPrinter;

public class ESCPSample2
{
	private ChkPrinterStatus	chkStatus;
	private ESCPOSPrinter posPtr;
	private final char ESC = ESCPOS.ESC;
	private final char LF = ESCPOS.LF;
	private int sts;
	
	public ESCPSample2()
	{
		posPtr = new ESCPOSPrinter("Shift_JIS");
		chkStatus = new ChkPrinterStatus();

	}
	
	public int receipt() throws UnsupportedEncodingException
    {
		sts = chkStatus.PrinterStatus(posPtr);
		if(sts != ESCPOSConst.CMP_SUCCESS) return sts;

		Calendar calendar = Calendar.getInstance();
		Date date = calendar.getTime();
		String today =(new SimpleDateFormat("yyyy-MM-dd-HH:mm:ss").format(date));

		posPtr.printNormal(ESC + "|cA" + ESC + "|bC" + ESC + "|2C" + "Receipt" + LF + LF);
        posPtr.printNormal(ESC + "|rA" + ESC + "|bC" + "TEL (123)-456-7890" + LF);
        posPtr.printNormal(ESC + "|cA" + ESC + "|bC" + "Thank you for coming to our shop!" + LF + LF);
	    posPtr.printNormal(ESC+"|cA" + today + "\n\n");

        posPtr.printNormal("Chicken                   $10.00" + LF);
        posPtr.printNormal("Hamburger                 $20.00" + LF);
        posPtr.printNormal("Pizza                     $30.00" + LF);
        posPtr.printNormal("Lemons                    $40.00" + LF);
        posPtr.printNormal("Drink                     $50.00" + LF + LF);
        posPtr.printNormal("Excluded tax             $150.00" + LF);

        posPtr.printNormal( ESC + "|uC" + "Tax(5%)                    $7.50" + LF);
        posPtr.printNormal( ESC + "|bC" + ESC + "|2C" + "Total    $157.50" + LF + LF);
        posPtr.printNormal( ESC + "|bC" + "Payment                  $200.00" + LF);
        posPtr.printNormal( ESC + "|bC" + "Change                    $42.50" + LF);
    
		return ESCPOSConst.CMP_SUCCESS;
    }
    
    
	public int sample1() throws UnsupportedEncodingException
	{
		final int center = ESCPOSConst.CMP_ALIGNMENT_CENTER;
		final int fntBold = ESCPOSConst.CMP_FNT_BOLD;
		final int fntULine = ESCPOSConst.CMP_FNT_UNDERLINE + ESCPOSConst.CMP_FNT_BOLD;
		final int textSize22 = ESCPOSConst.CMP_TXT_2WIDTH |ESCPOSConst.CMP_TXT_2HEIGHT;

		final byte [] CMD_BOLD0 = { 0x1b, 0x45, 0x00 }; // NoBold
		final byte [] CMD_BOLD1 = { 0x1b, 0x45, 0x01 }; //Bold
		final byte [] CMD_ULINE0 = { 0x1b, 0x2d, 0x30 }; // NoUnderline
		final byte [] CMD_W1H1 = { 0x1d, 0x21, 0x00 }; // Standard size
		final byte [] CMD_W2H2 = { 0x1d, 0x21, 0x11 }; // Double width/height

		final byte [] CMD_CENTER = { 0x1b, 0x61, 0x31 }; //Centering
		final byte [] CMD_RIGHT = { 0x1b, 0x61, 0x32 }; //Right alignment
		
		final String BOLD0 = new String( CMD_BOLD0 , "Shift_JIS");
		final String BOLD1 = new String( CMD_BOLD1 , "Shift_JIS");
		final String ULINE0 = new String( CMD_ULINE0, "Shift_JIS");
		final String W1H1 = new String( CMD_W1H1 , "Shift_JIS");
		final String W2H2 = new String( CMD_W2H2 , "Shift_JIS");
		final String CENTER = new String( CMD_CENTER, "Shift_JIS");
		final String RIGHT = new String( CMD_RIGHT , "Shift_JIS");

		final byte [] CMD_K_ULINE0 = { 0x1c, 0x2d, 0x30 }; // Kanji nounderline
		final String K_ULINE0 = new String( CMD_K_ULINE0, "Shift_JIS");

		StringBuffer sb = new StringBuffer();

		sts = chkStatus.PrinterStatus(posPtr);
		if(sts != ESCPOSConst.CMP_SUCCESS) return sts;

		posPtr.printText( ("Method : CENTER BOLD 2x2 漢字") +"\n", center, fntBold, textSize22 );

		sb.append( K_ULINE0 + ULINE0 + CENTER + BOLD1 + W2H2 );
		sb.append( ("Command : CENTER BOLD 2x2 漢字") +"\n" );
		sb.append( RIGHT + K_ULINE0 + ULINE0 + BOLD0 + W1H1 );
		sb.append( ("Command : RIGHT Non-BOLD 1x1 漢字") +"\n" );

		String s = sb.toString();
		posPtr.printNormal( s );
		posPtr.printText( ("Method : CENTER BOLD UNDERLINE 2x2漢字") + "\n", center, fntULine, textSize22 );

		posPtr.lineFeed(2);
		s = null;
		sb = null;
		
		return ESCPOSConst.CMP_SUCCESS;
	}
    
    public int sample2() throws UnsupportedEncodingException
    {
        sts = receipt();
        if(sts != ESCPOSConst.CMP_SUCCESS) return sts;
        
        posPtr.printBarCode("1234567890", ESCPOSConst.CMP_BCS_Code39, 40, 2, ESCPOSConst.CMP_ALIGNMENT_CENTER, ESCPOSConst.CMP_HRI_TEXT_BELOW);         
        posPtr.printNormal(ESC + "|cA" + ESC + "|4C" + ESC + "|bC" + "Thank you" + LF);
		posPtr.lineFeed(2);
		
		return ESCPOSConst.CMP_SUCCESS;
    }

    public int sample3() throws UnsupportedEncodingException
    {
        sts = receipt();
        if(sts != ESCPOSConst.CMP_SUCCESS) return sts;

        posPtr.printBarCode("1234567890", ESCPOSConst.CMP_BCS_Code39, 40, 2, ESCPOSConst.CMP_ALIGNMENT_CENTER, ESCPOSConst.CMP_HRI_TEXT_BELOW);
        posPtr.printBarCode("0123498765", ESCPOSConst.CMP_BCS_Code93, 40, 2, ESCPOSConst.CMP_ALIGNMENT_CENTER, ESCPOSConst.CMP_HRI_TEXT_BELOW);
        posPtr.printBarCode("0987654321", ESCPOSConst.CMP_BCS_ITF, 40, 2, ESCPOSConst.CMP_ALIGNMENT_CENTER, ESCPOSConst.CMP_HRI_TEXT_BELOW);
        posPtr.printBarCode("{ACODE 128", ESCPOSConst.CMP_BCS_Code128, 40, 2, ESCPOSConst.CMP_ALIGNMENT_CENTER, ESCPOSConst.CMP_HRI_TEXT_BELOW);
        posPtr.printBarCode("{BCode 128", ESCPOSConst.CMP_BCS_Code128, 40, 2, ESCPOSConst.CMP_ALIGNMENT_CENTER, ESCPOSConst.CMP_HRI_TEXT_BELOW);
        posPtr.printBarCode("{C12345", ESCPOSConst.CMP_BCS_Code128, 40, 2, ESCPOSConst.CMP_ALIGNMENT_CENTER, ESCPOSConst.CMP_HRI_TEXT_BELOW);
        posPtr.printBarCode("A1029384756A", ESCPOSConst.CMP_BCS_Codabar, 40, 2, ESCPOSConst.CMP_ALIGNMENT_CENTER, ESCPOSConst.CMP_HRI_TEXT_BELOW);
        posPtr.printNormal(ESC + "|cA" + ESC + "|4C" + ESC + "|bC" + "Thank you" + LF);
		posPtr.lineFeed(2);

		return ESCPOSConst.CMP_SUCCESS;
    }
    
    public int imageTest() throws IOException
    {
		sts = chkStatus.PrinterStatus(posPtr);
		if(sts != ESCPOSConst.CMP_SUCCESS) return sts;
		
		//posPtr.setDithering(ESCPOSConst.CMP_BITMAP_ERROR_DIFFUSION);
    	posPtr.printBitmap("//sdcard//temp//citizen//logo_s.jpg", ESCPOSConst.CMP_ALIGNMENT_CENTER);
    	posPtr.printBitmap("//sdcard//temp//citizen//sample_2.jpg", ESCPOSConst.CMP_ALIGNMENT_CENTER);
    	posPtr.printBitmap("//sdcard//temp//citizen//sample_3.jpg", ESCPOSConst.CMP_ALIGNMENT_LEFT);
    	posPtr.printBitmap("//sdcard//temp//citizen//sample_4.jpg", ESCPOSConst.CMP_ALIGNMENT_RIGHT);
		posPtr.lineFeed(2);

		return ESCPOSConst.CMP_SUCCESS;
    }
    
    public int japaneseTest() throws UnsupportedEncodingException
    {
    	ESCPOSPrinter escpJapan = new ESCPOSPrinter("S-JIS");
    	
		sts = chkStatus.PrinterStatus(posPtr);
		if(sts != ESCPOSConst.CMP_SUCCESS) return sts;

    	for(int i=0;i<JapaneseSample.horizontal.length;i++)
    	{
    		for(int j=0;j<JapaneseSample.underline.length;j++)
    		{
    			escpJapan.printNormal(JapaneseSample.horizontal[i]+
    								JapaneseSample.underline[j]+
    								JapaneseSample.hiragana[0]+"\r\n");		
    		}
    	}

    	return ESCPOSConst.CMP_SUCCESS;
    }
    
    public int japaneseTest2() throws UnsupportedEncodingException
    {
    	ESCPOSPrinter escpJapan = new ESCPOSPrinter("S-JIS");
	    
		sts = chkStatus.PrinterStatus(posPtr);
		if(sts != ESCPOSConst.CMP_SUCCESS) return sts;

    	escpJapan.printText(JapaneseSample.hiragana[0]+"\r\n", 
    			ESCPOSConst.CMP_ALIGNMENT_RIGHT, 
    			ESCPOSConst.CMP_FNT_DEFAULT, 
    			ESCPOSConst.CMP_TXT_2WIDTH);
    	
    	escpJapan.printText(JapaneseSample.hiragana[0]+"\r\n", 
    			ESCPOSConst.CMP_ALIGNMENT_LEFT, 
    			ESCPOSConst.CMP_FNT_DEFAULT, 
    			ESCPOSConst.CMP_TXT_2WIDTH | ESCPOSConst.CMP_TXT_2HEIGHT);
	    
	    escpJapan.printText(JapaneseSample.hiragana[0]+"\r\n", 
	    		ESCPOSConst.CMP_ALIGNMENT_CENTER, 
	    		ESCPOSConst.CMP_FNT_DEFAULT, 
	    		ESCPOSConst.CMP_TXT_3WIDTH | ESCPOSConst.CMP_TXT_3HEIGHT);
	    
	    escpJapan.printText(JapaneseSample.hiragana[0]+"\r\n", 
	    		ESCPOSConst.CMP_ALIGNMENT_LEFT, 
	    		ESCPOSConst.CMP_FNT_DEFAULT, 
	    		ESCPOSConst.CMP_TXT_1WIDTH | ESCPOSConst.CMP_TXT_1HEIGHT);

		return ESCPOSConst.CMP_SUCCESS;
    }

    public String emulCheck()
	{
		String result = "";
		sts = posPtr.getEmulation();
		if(sts == ESCPOSConst.EMUL_CPCL)
			result = "CPCL";
		else if(sts == ESCPOSConst.EMUL_ESCPOS)
			result = "ESCPOS";
		else
			result = "Unknown";
		return result;		
	}

    public int printAndroidFont() throws UnsupportedEncodingException
	{
    	int nLineWidth = 384;
    	String data = "Receipt";
//    	String data = "영수증";
    	Typeface typeface = null;

		sts = chkStatus.PrinterStatus(posPtr);
		if(sts != ESCPOSConst.CMP_SUCCESS) return sts;

    	try
		{
			posPtr.printAndroidFont(data, nLineWidth, 100, ESCPOSConst.CMP_ALIGNMENT_CENTER);
			posPtr.lineFeed(2);
			posPtr.printAndroidFont("Left Alignment", nLineWidth, 24, ESCPOSConst.CMP_ALIGNMENT_LEFT);
			posPtr.printAndroidFont("Center Alignment", nLineWidth, 24, ESCPOSConst.CMP_ALIGNMENT_CENTER);
			posPtr.printAndroidFont("Right Alignment", nLineWidth, 24, ESCPOSConst.CMP_ALIGNMENT_RIGHT);

			posPtr.lineFeed(2);
			posPtr.printAndroidFont(Typeface.SANS_SERIF, "SANS_SERIF : 1234iwIW", nLineWidth, 24, ESCPOSConst.CMP_ALIGNMENT_LEFT);
			posPtr.printAndroidFont(Typeface.SERIF, "SERIF : 1234iwIW", nLineWidth, 24, ESCPOSConst.CMP_ALIGNMENT_LEFT);
			posPtr.printAndroidFont(typeface.MONOSPACE, "MONOSPACE : 1234iwIW", nLineWidth, 24, ESCPOSConst.CMP_ALIGNMENT_LEFT);

			posPtr.lineFeed(2);
			posPtr.printAndroidFont(Typeface.SANS_SERIF, "SANS : 1234iwIW", nLineWidth, 24, ESCPOSConst.CMP_ALIGNMENT_LEFT);
			posPtr.printAndroidFont(Typeface.SANS_SERIF, true, "SANS BOLD : 1234iwIW", nLineWidth, 24, ESCPOSConst.CMP_ALIGNMENT_LEFT);
			posPtr.printAndroidFont(Typeface.SANS_SERIF, true, false, "SANS BOLD : 1234iwIW", nLineWidth, 24, ESCPOSConst.CMP_ALIGNMENT_LEFT);
			posPtr.printAndroidFont(Typeface.SANS_SERIF, false, true, "SANS ITALIC : 1234iwIW", nLineWidth, 24, ESCPOSConst.CMP_ALIGNMENT_LEFT);
			posPtr.printAndroidFont(Typeface.SANS_SERIF, true, true, "SANS BOLD ITALIC : 1234iwIW", nLineWidth, 24, ESCPOSConst.CMP_ALIGNMENT_LEFT);
			posPtr.printAndroidFont(Typeface.SANS_SERIF, true, true, true, "SANS B/I/U : 1234iwIW", nLineWidth, 24, ESCPOSConst.CMP_ALIGNMENT_LEFT);

			posPtr.lineFeed(2);
			posPtr.printAndroidFont(Typeface.SERIF, "SERIF : 1234iwIW", nLineWidth, 24, ESCPOSConst.CMP_ALIGNMENT_LEFT);
			posPtr.printAndroidFont(Typeface.SERIF, true, "SERIF BOLD : 1234iwIW", nLineWidth, 24, ESCPOSConst.CMP_ALIGNMENT_LEFT);
			posPtr.printAndroidFont(Typeface.SERIF, true, false, "SERIF BOLD : 1234iwIW", nLineWidth, 24, ESCPOSConst.CMP_ALIGNMENT_LEFT);
			posPtr.printAndroidFont(Typeface.SERIF, false, true, "SERIF ITALIC : 1234iwIW", nLineWidth, 24, ESCPOSConst.CMP_ALIGNMENT_LEFT);
			posPtr.printAndroidFont(Typeface.SERIF, true, true, "SERIF BOLD ITALIC : 1234iwIW", nLineWidth, 24, ESCPOSConst.CMP_ALIGNMENT_LEFT);
			posPtr.printAndroidFont(Typeface.SERIF, true, true, true, "SERIF B/I/U : 1234iwIW", nLineWidth, 24, ESCPOSConst.CMP_ALIGNMENT_LEFT);

			posPtr.lineFeed(2);
			posPtr.printAndroidFont(Typeface.MONOSPACE, "MONOSPACE : 1234iwIW", nLineWidth, 24, ESCPOSConst.CMP_ALIGNMENT_LEFT);
			posPtr.printAndroidFont(Typeface.MONOSPACE, true, "MONO BOLD : 1234iwIW", nLineWidth, 24, ESCPOSConst.CMP_ALIGNMENT_LEFT);
			posPtr.printAndroidFont(Typeface.MONOSPACE, true, false, "MONO BOLD : 1234iwIW", nLineWidth, 24, ESCPOSConst.CMP_ALIGNMENT_LEFT);
			posPtr.printAndroidFont(Typeface.MONOSPACE, false, true, "MONO ITALIC : 1234iwIW", nLineWidth, 24, ESCPOSConst.CMP_ALIGNMENT_LEFT);
			posPtr.printAndroidFont(Typeface.MONOSPACE, true, true, "MONO BOLD ITALIC: 1234iwIW", nLineWidth, 24, ESCPOSConst.CMP_ALIGNMENT_LEFT);
			posPtr.printAndroidFont(Typeface.MONOSPACE, true, true, true, "MONO B/I/U: 1234iwIW", nLineWidth, 24, ESCPOSConst.CMP_ALIGNMENT_LEFT);

			posPtr.lineFeed(4);
		}
		catch (IOException e)
		{
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		return ESCPOSConst.CMP_SUCCESS;
	}	

    public int printMultilingualFont() throws UnsupportedEncodingException
	{
    	int nLineWidth = 384;
    	String Koreandata = "영수증";
    	String Turkishdata = "Turkish(İ,Ş,Ğ)";
    	String Russiandata = "Получение";
    	String Arabicdata = "الإيصال";
    	String Greekdata = "Παραλαβή";
    	String Japanesedata = "領収書";
    	String GB2312data = "收据";
    	String BIG5data = "收據";

		sts = chkStatus.PrinterStatus(posPtr);
		if(sts != ESCPOSConst.CMP_SUCCESS) return sts;

    	try
		{
			posPtr.printAndroidFont("Korean Font", nLineWidth, 24, ESCPOSConst.CMP_ALIGNMENT_LEFT);
    		// Korean 100-dot size font in android device.
        	posPtr.printAndroidFont(Koreandata, nLineWidth, 100, ESCPOSConst.CMP_ALIGNMENT_CENTER);

			posPtr.printAndroidFont("Turkish Font", nLineWidth, 24, ESCPOSConst.CMP_ALIGNMENT_LEFT);
    		// Turkish 50-dot size font in android device.
        	posPtr.printAndroidFont(Turkishdata, nLineWidth, 50, ESCPOSConst.CMP_ALIGNMENT_CENTER);

			posPtr.printAndroidFont("Russian Font", 384, 24, ESCPOSConst.CMP_ALIGNMENT_LEFT);
    		// Russian 60-dot size font in android device.
        	posPtr.printAndroidFont(Russiandata, nLineWidth, 60, ESCPOSConst.CMP_ALIGNMENT_CENTER);

			posPtr.printAndroidFont("Arabic Font", nLineWidth, 24, ESCPOSConst.CMP_ALIGNMENT_LEFT);
    		// Arabic 100-dot size font in android device.
        	posPtr.printAndroidFont(Arabicdata, nLineWidth, 100, ESCPOSConst.CMP_ALIGNMENT_CENTER);

			posPtr.printAndroidFont("Greek Font", nLineWidth, 24, ESCPOSConst.CMP_ALIGNMENT_LEFT);
    		// Greek 60-dot size font in android device.
        	posPtr.printAndroidFont(Greekdata, nLineWidth, 60, ESCPOSConst.CMP_ALIGNMENT_CENTER);

			posPtr.printAndroidFont("Japanese Font", nLineWidth, 24, ESCPOSConst.CMP_ALIGNMENT_LEFT);
        	// Japanese 100-dot size font in android device.
        	posPtr.printAndroidFont(Japanesedata, nLineWidth, 100, ESCPOSConst.CMP_ALIGNMENT_CENTER);

			posPtr.printAndroidFont("GB2312 Font", nLineWidth, 24, ESCPOSConst.CMP_ALIGNMENT_LEFT);
    		// GB2312 100-dot size font in android device.
        	posPtr.printAndroidFont(GB2312data, nLineWidth, 100, ESCPOSConst.CMP_ALIGNMENT_CENTER);

			posPtr.printAndroidFont("BIG5 Font", nLineWidth, 24, ESCPOSConst.CMP_ALIGNMENT_LEFT);
    		// BIG5 100-dot size font in android device.
        	posPtr.printAndroidFont(BIG5data, nLineWidth, 100, ESCPOSConst.CMP_ALIGNMENT_CENTER);

        	posPtr.lineFeed(4);
		}
		catch (IOException e)
		{
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		return ESCPOSConst.CMP_SUCCESS;
	}

	public int printingResults() throws UnsupportedEncodingException
    {
		sts = posPtr.printerCheck(5000, true);
		if(sts != ESCPOSConst.CMP_SUCCESS) return sts;
		
		sts = posPtr.status();
		if(sts != ESCPOSConst.CMP_SUCCESS) return sts;
		
		
		posPtr.printNormal(ESC + "|cA" + ESC + "|bC" + ESC + "|2C" + "Receipt" + LF + LF);
        posPtr.printNormal(ESC + "|rA" + ESC + "|bC" + "TEL (123)-456-7890" + LF);
        posPtr.printNormal(ESC + "|cA" + ESC + "|bC" + "Thank you for coming to our shop!" + LF + LF);

        posPtr.printNormal("Chicken                   $10.00" + LF);
        posPtr.printNormal("Hamburger                 $20.00" + LF);
        posPtr.printNormal("Pizza                     $30.00" + LF);
        posPtr.printNormal("Lemons                    $40.00" + LF);
        posPtr.printNormal("Drink                     $50.00" + LF + LF);
        posPtr.printNormal("Excluded tax             $150.00" + LF);

        posPtr.printNormal( ESC + "|uC" + "Tax(5%)                    $7.50" + LF);
        posPtr.printNormal( ESC + "|bC" + ESC + "|2C" + "Total   $157.50" + LF + LF);
        posPtr.printNormal( ESC + "|bC" + "Payment                  $200.00" + LF);
        posPtr.printNormal( ESC + "|bC" + "Change                    $42.50" + LF);
        
        sts = posPtr.printerResults();
        return sts;
    }

	public int printFontB() throws UnsupportedEncodingException
    {
		sts = chkStatus.PrinterStatus(posPtr);
		if(sts != ESCPOSConst.CMP_SUCCESS) return sts;

		posPtr.printNormal(ESC+"|N");                               // Normal（標準）

        posPtr.printNormal( "printNormal あいうえお, CMP_ALIGNMENT_CENTER, CMP_FNT_FONTB, CMP_TXT_1WIDTH \n" );
        posPtr.printText( "printText あいうえお\n\n", ESCPOSConst.CMP_ALIGNMENT_CENTER, ESCPOSConst.CMP_FNT_FONTB, ESCPOSConst.CMP_TXT_1WIDTH );

        posPtr.printNormal( "printNormal あいうえお, CMP_ALIGNMENT_CENTER, CMP_FNT_FONTB, CMP_TXT_2WIDTH \n" );
        posPtr.printText( "printText あいうえお\n\n", ESCPOSConst.CMP_ALIGNMENT_CENTER, ESCPOSConst.CMP_FNT_FONTB, ESCPOSConst.CMP_TXT_2WIDTH );

        posPtr.printNormal( "printNormal あいうえお, CMP_ALIGNMENT_CENTER, CMP_FNT_FONTB, CMP_TXT_3WIDTH \n" );
        posPtr.printText( "printText あいうえお\n\n", ESCPOSConst.CMP_ALIGNMENT_CENTER, ESCPOSConst.CMP_FNT_FONTB, ESCPOSConst.CMP_TXT_3WIDTH );

        posPtr.printNormal( "printNormal あいうえお, CMP_ALIGNMENT_CENTER, CMP_FNT_FONTB, CMP_TXT_3HEIGHT \n" );
        posPtr.printText( "printText あいうえお\n\n", ESCPOSConst.CMP_ALIGNMENT_CENTER, ESCPOSConst.CMP_FNT_FONTB, ESCPOSConst.CMP_TXT_3HEIGHT );

        posPtr.printNormal( "printNormal あいうえお, CMP_ALIGNMENT_RIGHT, CMP_FNT_BOLD, CMP_TXT_8HEIGHT \n" );
        posPtr.printText( "printText あいうえお\n\n", ESCPOSConst.CMP_ALIGNMENT_RIGHT, ESCPOSConst.CMP_FNT_BOLD, ESCPOSConst.CMP_TXT_8HEIGHT );

        posPtr.printNormal( "printNormal あいうえお, CMP_ALIGNMENT_CENTER, CMP_FNT_UNDERLINE, CMP_TXT_4WIDTH \n" );
        posPtr.printText( "printText あいうえお\n\n", ESCPOSConst.CMP_ALIGNMENT_CENTER, ESCPOSConst.CMP_FNT_UNDERLINE, ESCPOSConst.CMP_TXT_4WIDTH );

        posPtr.printNormal( "printNormal あいうえお, CMP_ALIGNMENT_RIGHT, CMP_FNT_DEFAULT, CMP_TXT_2HEIGHT \n" );
        posPtr.printText( "printText あいうえお\n\n", ESCPOSConst.CMP_ALIGNMENT_RIGHT, ESCPOSConst.CMP_FNT_DEFAULT, ESCPOSConst.CMP_TXT_2HEIGHT );

        posPtr.printNormal( "printNormal あいうえお\n" );

        posPtr.lineFeed(4);

		return ESCPOSConst.CMP_SUCCESS;
    }

	public int printerStatus() throws UnsupportedEncodingException
    {
		sts = chkStatus.PrinterStatus(posPtr);
		if(sts != ESCPOSConst.CMP_SUCCESS) return sts;

		return sts;
    }
}
