package com.citizen.app.dukpt;

import java.io.IOException;

import com.citizen.app.assist.DebugPrint;
import com.citizen.app.msrtest.R;
import com.citizen.jpos.command.ESCPOSConst;
import com.citizen.request.android.DUKPTMSR;

import android.app.Activity;
import android.app.ProgressDialog;
import android.content.Context;
import android.os.Bundle;
import android.os.Handler;
import android.os.Message;
import android.util.Log;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;
import android.widget.CheckBox;
import android.widget.CompoundButton;
import android.widget.CompoundButton.OnCheckedChangeListener;
import android.widget.EditText;
import android.widget.Toast;

public class DUKPTMenu extends Activity 
{    
	private static final String TAG = "MSRMenu";
	
	private static EditText msrDataText;
	private static CheckBox track1Check;
	private static CheckBox track2Check;
	private static CheckBox track3Check;
	private static CheckBox hexCheck;
	private static Button readButton;
	private static Button cancelButton;
	
	private static Context context;
	
	private DUKPTMSR dukptMSR;
	private static String txtData;
	private static String hexData;
	
	/** Called when the activity is first created. */
    @Override
    public void onCreate(Bundle savedInstanceState) 
    {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.dukpt_msr_menu);
        
        context = this;
        
        // DUKPT MSR
        dukptMSR = DUKPTMSR.getInstance();
        dukptMSR.setHandler(readHandler);
        
        // UI
        readButton = (Button) findViewById(R.id.buttonMSRRead);
        cancelButton = (Button) findViewById(R.id.buttonMSRCancel);
        track1Check = (CheckBox) findViewById(R.id.checkBoxTrack1);
        track2Check = (CheckBox) findViewById(R.id.checkBoxTrack2);
        track3Check = (CheckBox) findViewById(R.id.checkBoxTrack3);
        hexCheck = (CheckBox) findViewById(R.id.checkBoxHex);
        msrDataText = (EditText) findViewById(R.id.msrDataField);
        
        readButton.setOnClickListener(msrReadClickListener);
        cancelButton.setOnClickListener(msrCancelClickListener);
        hexCheck.setOnCheckedChangeListener(hexChangeListener);
        
    }

    ProgressDialog dialog;
    
    OnClickListener msrReadClickListener = new OnClickListener()
    {
		
		@Override
		public void onClick(View v)
		{
			try
			{
				// TODO
				// Check Box 
				if(ESCPOSConst.CMP_SUCCESS == dukptMSR.selectTrack(trackValue()))
				{
					Log.d(TAG,"select success");
					if(ESCPOSConst.CMP_SUCCESS == dukptMSR.readMSR())
					{
						statusUI(true);
						Log.d(TAG,"read success");
					}
					else
					{
						Toast.makeText(context, "Failed to changing MSR mode. Please try again.", Toast.LENGTH_SHORT).show();
						Log.d(TAG,"read failed");		
					}
				}
				else
				{
					Toast.makeText(context, "Failed to changing MSR mode. Please try again.", Toast.LENGTH_SHORT).show();
					Log.d(TAG,"select failed");
				}
			}
			catch (IOException e)
			{
				Log.e(TAG,e.getMessage());	
			}
			catch (InterruptedException e)
			{
				Log.e(TAG,e.getMessage());
			}		
		}
	};
    
	OnClickListener msrCancelClickListener = new OnClickListener()
	{
		
		@Override
		public void onClick(View v)
		{
			// TODO Auto-generated method stub
			try
			{
				if(dukptMSR.readCancel() == ESCPOSConst.CMP_SUCCESS)
				{
					statusUI(false);
					Log.e(TAG,"Cancel Success");
				}
				else
				{
					Toast.makeText(context, "Failed to changing Normal mode. Please try again.", Toast.LENGTH_SHORT).show();
					Log.e(TAG,"Cancel Failed");
				}
			}
			catch (IOException e)
			{
				Log.e(TAG,e.getMessage());
			}
			catch (InterruptedException e)
			{
				Log.e(TAG,e.getMessage());
			}
		}
	};
	
	
	OnCheckedChangeListener hexChangeListener = new OnCheckedChangeListener()
	{
		
		@Override
		public void onCheckedChanged(CompoundButton buttonView, boolean isChecked)
		{
			// TODO Auto-generated method stub
			if(isChecked)
			{
				msrDataText.setText(hexData);
			}
			else
			{
				msrDataText.setText(txtData);	
			}
		}
	};
	
    
    @Override
    protected void onDestroy()
    {
    	Log.w(TAG,"onDestroy");
    	try
		{
    		dukptMSR.releaseInstance();
		}
		catch (InterruptedException e)
		{
			Log.e(TAG,e.getMessage(),e);
		}
		catch (IOException e)
		{
			Log.e(TAG,e.getMessage(),e);
		}
    	super.onDestroy();
    }
    
    
    protected int trackValue()
    {
    	int ret = 0;
    	if(track1Check.isChecked())
    	{
    		ret = ret + 1;
    	}
    	if(track2Check.isChecked())
    	{
    		ret = ret + 2;
    	}
    	if(track3Check.isChecked())
    	{
    		ret = ret + 4;
    	}
    	
    	// All Three tracks Required -> Any
    	if(ret == 7)
    		ret = 0;
    	else if(ret == 3)
    		ret = 8;
    	else if(ret == 6)
    		ret = 9;
    	
    	Log.d(TAG,"trackValue "+ret);
    	return ret;
    }
    
    protected static void statusUI(boolean isMsrMode)
    {
    	readButton.setEnabled(!isMsrMode);
        cancelButton.setEnabled(isMsrMode);
        track1Check.setEnabled(!isMsrMode);
        track2Check.setEnabled(!isMsrMode);
        track3Check.setEnabled(!isMsrMode);
        if(isMsrMode)
        {
        	msrDataText.setText("");
        	Toast.makeText(context, "Changed MSR Status. Please swipe a card.", Toast.LENGTH_SHORT).show();
        }
        else        
        	Toast.makeText(context, "Changed Normal Status.", Toast.LENGTH_SHORT).show();
    }
    
    // ================================================================================================ //
    // Track Data Update Handler. - Read Complete.
    // ================================================================================================ //
    final static Handler readHandler = new Handler()
    {
    	@Override
    	public void handleMessage(Message msg) 
    	{
    		Bundle bundle;
    		super.handleMessage(msg);
			bundle = (Bundle) msg.obj;
			if(bundle.size() > 1)
    		{    			
    			// rawData - MSR Data.
    			byte [] rawData = bundle.getByteArray("RawData");
    			int rawLength = bundle.getInt("RawDataSize");
    			
    			if(rawData != null)
    			{
    				txtData = new String(rawData);
    				hexData = DebugPrint.getHexString(rawData, rawLength);
    				
    				if(hexCheck.isChecked())
    					msrDataText.setText(hexData);
    				else
    					msrDataText.setText(txtData);
        			
    				Toast.makeText(context, rawLength+" bytes read from MSR", Toast.LENGTH_SHORT).show();
    			}
    			Log.d(TAG,"size "+rawLength);
    		}
    	}
    };
}